Struct dswt::Token

source ·
pub struct Token {
    pub version: u8,
    pub algorithm: Algorithm,
    pub payload: HashMap<String, String>,
    pub hash: String,
}
A struct that holds information about a Delimeter Separated Web Token. It is not reccomended to create a token directly using this struct, instead create one through the TokenManager struct.

Fields

version: u8

version of the token, this is automatically set to the crate version and should not be changed

algorithm: Algorithm

Te algorithm used to hash the payload

payload: HashMap<String, String>

payload of the token stored in a hashmap as key-value pairs

hash: String

hash of the token that gets generated when the token is created, it is used to verify the token is valid this is automatically set when the token is created and should not be changed

Implementations

source

impl Token

source

pub fn new( algorithm: Algorithm, payload: HashMap<String, String>, key: &str, ) -> Self

Create a new token with the given algorithm, payload, and key

source

pub fn get_hash(&self, key: &str) -> String

Get the hash of the token using the given key